@@ -3,7 +3,7 @@ test_that("test export codelist json", {
 
   # single codelist
   codes <- newCodelist(list("disease" = c(1L, 2L, 3L)))
-  cs_path <- tempdir("concepts")
+  dir.create(cs_path <- file.path(tempdir(), uniqueTableName()))
   expect_no_error(exportCodelist(
     x = codes,
     path = cs_path
@@ -15,7 +15,6 @@ test_that("test export codelist json", {
     "disease X" = c(1L, 2L, 3L),
     "disease Y" = c(4L, 5L)
   )
-  cs_path <- tempdir("concepts")
   expect_no_error(exportCodelist(
     x = codes,
     path = cs_path
@@ -39,13 +38,12 @@ test_that("test export codelist json", {
 test_that("test export codelist csv", {
   # single codelist
   codes <- newCodelist(list("disease" = c(1L, 2L, 3L)))
-  cs_path <- tempdir("concepts")
+  dir.create(cs_path <- file.path(tempdir(), uniqueTableName()))
   expect_no_error(exportCodelist(x = codes, path = cs_path, type = "csv"))
   expect_true("disease.csv" %in% list.files(cs_path))
 
   # multiple codelists
   codes <- list("disease X" = c(1L, 2L, 3L), "disease Y" = c(4L, 5L))
-  cs_path <- tempdir("concepts")
   expect_no_error(exportCodelist(x = codes, path = cs_path, type = "csv"))
   expect_true("disease X.csv" %in% list.files(cs_path))
   expect_true("disease Y.csv" %in% list.files(cs_path))
